Property Index
$#! · 0-9 · A · B · C · D · E · F · G · H · I · J · K · L · M · N · O · P · Q · R · S · T · U · V · W · X · Y · Z

S |
| scaleToHiddenSeries, Axis
| sectionMargin, $.jqplot.FunnelRenderer
| series, jqPlot
| seriesColors, jqPlot
| seriesDefaults, jqPlot
| seriesLabelIndex, $.jqplot.PointLabels
| seriesToggle
| seriesToggleReplot
| shadow $.jqplot.CanvasOverlay$.jqplot.MarkerRenderer$.jqplot.Trendline Grid
| shadowAlpha $.jqplot.BarRenderer$.jqplot.CanvasOverlay$.jqplot.DonutRenderer$.jqplot.FunnelRenderer$.jqplot.MarkerRenderer$.jqplot.MeterGaugeRenderer$.jqplot.PieRenderer$.jqplot.Trendline Grid Series
| shadowAngle $.jqplot.CanvasOverlay$.jqplot.MarkerRenderer$.jqplot.Trendline Grid Series
| shadowColor, Grid
| shadowDepth $.jqplot.BarRenderer$.jqplot.CanvasOverlay$.jqplot.DonutRenderer$.jqplot.FunnelRenderer$.jqplot.MarkerRenderer$.jqplot.MeterGaugeRenderer$.jqplot.PieRenderer$.jqplot.Trendline Grid Series
| shadowOffset $.jqplot.BarRenderer$.jqplot.CanvasOverlay$.jqplot.DonutRenderer$.jqplot.FunnelRenderer$.jqplot.MarkerRenderer$.jqplot.MeterGaugeRenderer$.jqplot.PieRenderer$.jqplot.Trendline Grid Series
| shadowRenderer, $.jqplot.MarkerRenderer
| shadowWidth, Grid
| shapeRenderer, $.jqplot.MarkerRenderer
| show $.jqplot.AxisLabelRenderer$.jqplot.AxisTickRenderer$.jqplot.CanvasAxisLabelRenderer$.jqplot.CanvasAxisTickRenderer$.jqplot.CanvasOverlay$.jqplot.Cursor$.jqplot.Highlighter$.jqplot.LineRenderer$.jqplot.MarkerRenderer$.jqplot.PointLabels$.jqplot.Trendline Axis Legend Series Title
| showBorders, $.jqplot.MekkoRenderer
| showCursorLegend, $.jqplot.Cursor
| showDataLabels $.jqplot.DonutRenderer$.jqplot.FunnelRenderer$.jqplot.PieRenderer
| showGridline $.jqplot.AxisTickRenderer$.jqplot.CanvasAxisTickRenderer
| showHorizontalLine, $.jqplot.Cursor
| showLabel $.jqplot.AxisTickRenderer$.jqplot.CanvasAxisLabelRenderer$.jqplot.CanvasAxisTickRenderer Axis Series
| showLabels $.jqplot.BubbleRenderer Legend
| showLine, Series
| showLines, $.jqplot.LineRenderer
| showMark $.jqplot.AxisTickRenderer$.jqplot.CanvasAxisTickRenderer
| showMarker $.jqplot.Highlighter Series
| showMinorTicks, Axis
| showSwatch, Legend
| showTickLabels, $.jqplot.MeterGaugeRenderer
| showTickMarks, Axis
| showTicks $.jqplot.MeterGaugeRenderer Axis
| showTooltip $.jqplot.CanvasOverlay$.jqplot.Cursor$.jqplot.Highlighter
| showTooltipDataPosition, $.jqplot.Cursor
| showTooltipGridPosition, $.jqplot.Cursor
| showTooltipOutsideZoom, $.jqplot.Cursor
| showTooltipPrecision, $.jqplot.CanvasOverlay
| showTooltipUnitPosition, $.jqplot.Cursor
| showVerticalLine, $.jqplot.Cursor
| size $.jqplot.AxisTickRenderer$.jqplot.MarkerRenderer
| sizeAdjust, $.jqplot.Highlighter
| sliceMargin $.jqplot.DonutRenderer$.jqplot.PieRenderer
| smooth, $.jqplot.LineRenderer
| sortData, jqPlot
| sortMergedLabels, $.jqplot.CategoryAxisRenderer
| stackedValue, $.jqplot.PointLabels
| stackSeries, jqPlot
| start, Line
| startAngle $.jqplot.DonutRenderer$.jqplot.PieRenderer
| stop, Line
| strokeRect, $.jqplot.shapeRenderer
| strokeStyle, $.jqplot.shapeRenderer
| style $.jqplot.Cursor$.jqplot.MarkerRenderer
| suffix, $.jqplot.AxisTickRenderer
| synchronizeHighlight
| syncTicks, Axis

> this.scaleToHiddenSeries = false

True to include hidden series when computing axes bounds and scaling.

> this.sectionMargin = 6

spacing between funnel sections in pixels.

> this.series = []

Array of series object options.

> this.seriesColors = $.jqplot.config.defaultColors

Ann array of CSS color specifications that will be applied, in order, to the series in the plot.

> seriesDefaults: {}, series:[] }

default options that will be applied to all series.

> this.seriesLabelIndex = null

array index for location of labels within data point arrays.

> this.seriesToggle = 'normal'

false to not enable series on/off toggling on the legend.

> this.seriesToggleReplot = false

True to replot the chart after toggling series on/off.
whether or not to draw a shadow on the line

> this.shadow = true

whether or not to draw a shadow on the line

> this.shadow = true

true or false, whether or not to show the shadow.

> this.shadow = true

whether to show a shadow behind the grid.

> this.shadowAlpha = 0.08

transparency of the shadow (0 = transparent, 1 = opaque)
Alpha channel transparency of shadow.

> this.shadowAlpha = 0.07

transparency of the shadow (0 = transparent, 1 = opaque)

> this.shadowAlpha = 0.07

transparency of the shadow (0 = transparent, 1 = opaque)

> this.shadowAlpha = '0.07'

Alpha channel transparency of shadow.

> this.shadowAlpha = 0.07

transparency of the shadow (0 = transparent, 1 = opaque)

> this.shadowAlpha = 0.07

transparency of the shadow (0 = transparent, 1 = opaque)

> this.shadowAlpha = 0.07

Alpha transparency of the shadow.

> this.shadowAlpha = '0.07'

Alpha channel transparency of shadow.

> this.shadowAlpha = '0.1'

Alpha channel transparency of shadow.
Shadow angle in degrees

> this.shadowAngle = 45

Shadow angle in degrees

> this.shadowAngle = 45

Angle of the shadow on the trend line.

> this.shadowAngle = 45

shadow angle in degrees

> this.shadowAngle = 45

Shadow angle in degrees

> this.shadowColor = null

an optional css color spec for the shadow in ‘rgba(n, n, n, n)’ form

> this.shadowDepth = 5

number of strokes to apply to the shadow, each stroke offset shadowOffset from the last.
Number of times shadow is stroked, each stroke offset shadowOffset from the last.

> this.shadowDepth = 5

number of strokes to apply to the shadow, each stroke offset shadowOffset from the last.

> this.shadowDepth = 5

number of strokes to apply to the shadow, each stroke offset shadowOffset from the last.

> this.shadowDepth = 3

Number of times shadow is stroked, each stroke offset shadowOffset from the last.

> this.shadowDepth = 4

number of strokes to apply to the shadow, each stroke offset shadowOffset from the last.

> this.shadowDepth = 5

number of strokes to apply to the shadow, each stroke offset shadowOffset from the last.

> this.shadowDepth = 3

number of strokes to make of the shadow.

> this.shadowDepth = 3

Number of times shadow is stroked, each stroke offset shadowOffset from the last.

> this.shadowDepth = 3

Number of times shadow is stroked, each stroke offset shadowOffset from the last.

> this.shadowOffset = 2

offset of the shadow from the slice and offset of each succesive stroke of the shadow from the last.
Shadow offset from line in pixels

> this.shadowOffset = 2

offset of the shadow from the slice and offset of each succesive stroke of the shadow from the last.

> this.shadowOffset = 2

offset of the shadow from the area and offset of each succesive stroke of the shadow from the last.

> this.shadowOffset = 1

Shadow offset from line in pixels

> this.shadowOffset = 2

offset of the shadow from the gauge ring and offset of each succesive stroke of the shadow from the last.

> this.shadowOffset = 2

offset of the shadow from the slice and offset of each succesive stroke of the shadow from the last.

> this.shadowOffset = 1.0

pixel offset for each stroke of the shadow.

> this.shadowOffset = 1.5

Offset of each shadow stroke from the border in pixels

> this.shadowOffset = 1.25

Shadow offset from line in pixels

> this.shadowRenderer = new $.jqplot.ShadowRenderer()

Renderer that will draws the shadows on the marker.

> this.shadowWidth = 3

width of the stoke for the shadow

> this.shapeRenderer = new $.jqplot.ShapeRenderer()

Renderer that will draw the marker.

> this.show = true

whether or not to show the tick (mark and label).

> this.show = true

whether or not to show the tick (mark and label).

> this.show = true

whether or not to show the tick (mark and label).

> this.show = true

whether or not to show the tick (mark and label).
true to show (draw), false to not draw.

> this.show = $.jqplot.config.enablePlugins

whether to show the cursor or not.

> this.show = $.jqplot.config.enablePlugins

true to show the highlight.
true to show the bands.

> this.show = true

whether or not to show the marker.

> this.show = $.jqplot.config.enablePlugins

show the labels or not.

> this.show = $.jqplot.config.enablePlugins

Wether or not to show the trend line.

> this.show = false

Wether to display the axis on the graph.

> this.show = false

Wether to display the legend on the graph.

> this.show = true

whether or not to draw the series.

> this.show = true

whether or not to show the title

> this.showBorders = true

True to draw borders lines between areas on the chart.

> this.showCursorLegend = false

Replace the plot legend with an enhanced legend displaying intersection information.

> this.showDataLabels = false

true to show data labels on slices.

> this.showDataLabels = false

true to show data labels on slices.

> this.showDataLabels = false

true to show data labels on slices.

> this.showGridline = true

whether or not to draw the gridline on the grid at this tick.

> this.showGridline = true

whether or not to draw the gridline on the grid at this tick.

> this.showHorizontalLine = false

draw a horizontal line across the plot which follows the cursor.

> this.showLabel = true

whether or not to show the label.

> this.showLabel = true

whether or not to show the label.

> this.showLabel = true

whether or not to show the label.

> this.showLabel = true

true to show the axis label.

> this.showLabel = true

true to show label for this series in the legend.

> this.showLabels = true

True to show labels on bubbles (if any), false to not show.

> this.showLabels = true

true to show the label text on the legend.

> this.showLine = true

whether to actually draw the line or not.
True to show lines at top and bottom of bands [default: false].

> this.showMark = true

whether or not to show the mark on the axis.

> this.showMark = true

whether or not to show the mark on the axis.

> this.showMarker = true

true to show the marker

> this.showMarker = true

whether or not to show the markers at the data points.

> this.showMinorTicks = true

Wether or not to show minor ticks.

> this.showSwatches = true

true to show the color swatches on the legend.

> this.showTickLabels = true

true to show tick labels next to ticks.

> this.showTickMarks = true

Wether to show the tick marks (line crossing grid) or not.

> this.showTicks = true

true to show ticks around gauge.

> this.showTicks = true

Wether to show the ticks (both marks and labels) or not.
Show a tooltip with data point values.

> this.showTooltip = true

show a cursor position tooltip.

> this.showTooltip = true

Show a tooltip with data point values.

> this.showTooltipDataPosition = false

Used with showVerticalLine to show intersecting data points in the tooltip.

> this.showTooltipGridPosition = false

show the grid pixel coordinates of the mouse.

> this.showTooltipOutsideZoom = false

True will keep updating the tooltip when zooming of the grid.
Controls how close to line cursor must be to show tooltip.

> this.showTooltipUnitPosition = true

show the unit (data) coordinates of the mouse.

> this.showVerticalLine = false

draw a vertical line across the plot which follows the cursor.

> this.size = 4

Length of the tick beyond the grid in pixels.

> this.size = 9.0

Size of the marker (diameter or circle, length of edge of square, etc.)

> this.sizeAdjust = 5

Pixels to add to the overall size of the highlight.

> this.sliceMargin = 0

angular spacing between donut slices in degrees.

> this.sliceMargin = 0

angular spacing between pie slices in degrees.

> this.renderer.smooth = false

True to draw a smoothed (interpolated) line through the data points with automatically computed number of smoothing points.

> this.sortData = true

false to not sort the data passed in by the user.

> this.sortMergedLabels = false

True to sort tick labels when labels are created by merging x axis values from multiple series.

> this.stackedValue = false

true to display value as stacked in a stacked plot.

> this.stackSeries = false

true or false, creates a stack or “mountain” plot.
[x, y] coordinates for the start of the line.

> this.startAngle = 0

Angle to start drawing donut in degrees.

> this.startAngle = 0

Angle to start drawing pie in degrees.

> stop: [] }

[x, y] coordinates for the end of the line.

> this.strokeRect = false

true to draw shape as a stroked rectangle.

> this.strokeStyle = '#999999'

css color spec for the stoke style

> this.style = 'crosshair'

CSS spec for cursor style

> this.style = 'filledCircle'

One of diamond, circle, square, x, plus, dash, filledDiamond, filledCircle, filledSquare

> this.suffix = ''

String to append to the tick label.

> this.synchronizeHighlight = false

Index of another series to highlight when this series is highlighted.

> this.syncTicks = null

true to try and synchronize tick spacing across multiple axes so that ticks and grid lines line up.
Close